@@ -4,6 +4,7 @@ from .feature_extraction import DeepFeatureExtractor
 from .feature_extraction import AugmentedDeepFeatureExtractor
 from .feature_extraction import GridDeepFeatureExtractor
 from .feature_extraction import GridAugmentedDeepFeatureExtractor
+from .feature_extraction import MaskedGridDeepFeatureExtractor
 
 # graph builders
 from .graph_builders import RAGGraphBuilder
@@ -45,6 +46,7 @@ __all__ = [
     'AugmentedDeepFeatureExtractor',
     'GridDeepFeatureExtractor',
     'GridAugmentedDeepFeatureExtractor',
+    'MaskedGridDeepFeatureExtractor',
     'RAGGraphBuilder',
     'KNNGraphBuilder',
     'ImageLoader',
