@@ -5,12 +5,16 @@ import math
 import warnings
 from abc import abstractmethod
 from pathlib import Path
+from collections import OrderedDict
+from copy import deepcopy
 from typing import Any, Callable, List, Optional, Tuple, Union
 
 import cv2
 import numpy as np
+import pandas as pd
 import torch
 import torchvision
+from histocartography.preprocessing.tissue_mask import GaussianTissueMask
 from histocartography.utils import dynamic_import_from
 from scipy.stats import skew
 from skimage.feature import greycomatrix, greycoprops
@@ -450,12 +454,12 @@ class InstanceMapPatchDataset(Dataset):
         fill_value: Optional[int] = 255,
         mean: Optional[List[float]] = None,
         std: Optional[List[float]] = None,
-        transform: Optional[Callable] = None
+        transform: Optional[Callable] = None,
+        with_instance_masking: Optional[bool] = False,
     ) -> None:
         """
         Create a dataset for a given image and extracted instance map with desired patches
-        of (patch_size, patch_size, 3). If fill_value is not None, it fills up pixels outside the
-        instance maps with this value (all channels).
+        of (patch_size, patch_size, 3). 
 
         Args:
             image (np.ndarray): RGB input image.
@@ -464,15 +468,17 @@ class InstanceMapPatchDataset(Dataset):
             stride (int): Desired stride for patch extraction. If None, stride is set to patch size. Defaults to None.
             resize_size (int): Desired resized size to input the network. If None, no resizing is done and the
                                patches of size patch_size are provided to the network. Defaults to None.
-            fill_value (Optional[int]): Value to fill outside the instance maps
-                                        (None means do not fill).
+            fill_value (Optional[int]): Value to fill outside the instance maps. Defaults to 255. 
             mean (list[float], optional): Channel-wise mean for image normalization.
             std (list[float], optional): Channel-wise std for image normalization.
             transform (Callable): Transform to apply. Defaults to None.
+            with_instance_masking (bool): If pixels outside instance should be masked. Defaults to False.
         """
         self.image = image
         self.instance_map = instance_map
         self.patch_size = patch_size
+        self.with_instance_masking = with_instance_masking
+        self.fill_value = fill_value
         self.stride = stride
         self.resize_size = resize_size
         self.mean = mean
@@ -498,7 +504,8 @@ class InstanceMapPatchDataset(Dataset):
         self.properties = regionprops(self.instance_map)
         self.warning_threshold = 0.75
         self.patch_coordinates = []
-        self.patch_instance_index = []
+        self.patch_region_count = []
+        self.patch_instance_ids = []
         self.patch_overlap = []
 
         basic_transforms = [transforms.ToPILImage()]
@@ -514,84 +521,68 @@ class InstanceMapPatchDataset(Dataset):
         self._precompute()
         self._warning()
 
-    def _add_patch(self, center_x: int, center_y: int, index: int) -> None:
+    def _add_patch(self, center_x: int, center_y: int, instance_index: int, region_count: int) -> None:
         """
         Extract and include patch information.
 
         Args:
-            center_x (int): Centroid x-coordinate of the patch.
-            center_y (int): Centroid y-coordinate of the patch.
-            index (int): Instance index to which the patch belongs.
+            center_x (int): Centroid x-coordinate of the patch wrt. the instance map.
+            center_y (int): Centroid y-coordinate of the patch wrt. the instance map.
+            instance_index (int): Instance index to which the patch belongs.
+            region_count (int): Region count indicates the location of the patch wrt. the list of patch coords.
         """
-        mask = np.zeros_like(self.instance_mask)
-        mask[center_y -
-             self.patch_size_2 -
-             self.offset_y: center_y +
-             self.patch_size_2 -
-             self.offset_y, center_x -
-             self.patch_size_2 -
-             self.offset_x: center_x +
-             self.patch_size_2 -
-             self.offset_x] = 1
-
-        overlap = np.sum(mask * self.instance_mask)
+        mask = self.instance_map[
+            center_y - self.patch_size_2: center_y + self.patch_size_2,
+            center_x - self.patch_size_2: center_x + self.patch_size_2
+        ]
+        overlap = np.sum(mask == instance_index)
         if overlap > self.threshold:
             loc = [center_x - self.patch_size_2, center_y - self.patch_size_2]
             self.patch_coordinates.append(loc)
-            self.patch_instance_index.append(index)
-            self.patch_count += 1
+            self.patch_region_count.append(region_count)
+            self.patch_instance_ids.append(instance_index)
             self.patch_overlap.append(overlap)
 
-    def _get_patch(self, loc: list) -> np.ndarray:
+    def _get_patch(self, loc: list, region_id: int = None) -> np.ndarray:
         """
         Extract patch from image.
 
         Args:
             loc (list): Top-left (x,y) coordinate of a patch.
+            region_id (int): Index of the region being processed. Defaults to None. 
         """
         min_x = loc[0]
         min_y = loc[1]
         max_x = min_x + self.patch_size
         max_y = min_y + self.patch_size
-        return self.image[min_y:max_y, min_x:max_x]
+
+        patch = copy.deepcopy(self.image[min_y:max_y, min_x:max_x])
+
+        if self.with_instance_masking:
+            instance_mask = ~(self.instance_map[min_y:max_y, min_x:max_x] == region_id)
+            patch[instance_mask, :] = self.fill_value
+
+        return patch
 
     def _precompute(self):
         """Precompute instance-wise patch information for all instances in the input image."""
-        for index, region in enumerate(self.properties):
-            self.patch_count = 0
+        for region_count, region in enumerate(self.properties):
 
-            # Extract center
+            # Extract centroid
             center_y, center_x = region.centroid
             center_x = int(round(center_x))
             center_y = int(round(center_y))
 
-            # Bounding box
+            # Extract bounding box
             min_y, min_x, max_y, max_x = region.bbox
 
-            # Instant mask
-            self.instance_mask = self.instance_map[
-                min_y - self.patch_size_2: max_y + self.patch_size_2,
-                min_x - self.patch_size_2: max_x + self.patch_size_2
-            ]
-            self.instance_mask = np.array(
-                self.instance_mask == region.label, dtype=int)
-            self.offset_x = min_x - self.patch_size_2
-            self.offset_y = min_y - self.patch_size_2
-
-            # Extract patch information (coordinates, index)
-            # quadrant 1
+            # Extract patch information around the centroid patch 
+            # quadrant 1 (includes centroid patch)
             y_ = copy.deepcopy(center_y)
             while y_ >= min_y:
                 x_ = copy.deepcopy(center_x)
                 while x_ >= min_x:
-                    self._add_patch(x_, y_, index)
-
-                    # Include at least one patch centered at the centroid
-                    if self.patch_count == 0:
-                        loc = [x_ - self.patch_size_2, y_ - self.patch_size_2]
-                        self.patch_coordinates.append(loc)
-                        self.patch_instance_index.append(index)
-                        self.patch_count += 1
+                    self._add_patch(x_, y_, region.label, region_count)
                     x_ -= self.stride
                 y_ -= self.stride
 
@@ -600,7 +591,7 @@ class InstanceMapPatchDataset(Dataset):
             while y_ >= min_y:
                 x_ = copy.deepcopy(center_x) + self.stride
                 while x_ <= max_x:
-                    self._add_patch(x_, y_, index)
+                    self._add_patch(x_, y_, region.label, region_count)
                     x_ += self.stride
                 y_ -= self.stride
 
@@ -609,7 +600,7 @@ class InstanceMapPatchDataset(Dataset):
             while y_ <= max_y:
                 x_ = copy.deepcopy(center_x)
                 while x_ >= min_x:
-                    self._add_patch(x_, y_, index)
+                    self._add_patch(x_, y_, region.label, region_count)
                     x_ -= self.stride
                 y_ += self.stride
 
@@ -618,7 +609,7 @@ class InstanceMapPatchDataset(Dataset):
             while y_ <= max_y:
                 x_ = copy.deepcopy(center_x) + self.stride
                 while x_ <= max_x:
-                    self._add_patch(x_, y_, index)
+                    self._add_patch(x_, y_, region.label, region_count)
                     x_ += self.stride
                 y_ += self.stride
 
@@ -642,9 +633,12 @@ class InstanceMapPatchDataset(Dataset):
         Returns:
             Tuple[int, torch.Tensor]: instance_index, image as tensor.
         """
-        patch = self._get_patch(self.patch_coordinates[index])
+        patch = self._get_patch(
+            self.patch_coordinates[index],
+            self.patch_instance_ids[index]
+        )
         patch = self.dataset_transform(patch)
-        return self.patch_instance_index[index], patch
+        return self.patch_region_count[index], patch
 
     def __len__(self) -> int:
         """
@@ -671,6 +665,7 @@ class DeepFeatureExtractor(FeatureExtractor):
         fill_value: int = 255,
         num_workers: int = 0,
         verbose: bool = False,
+        with_instance_masking: bool = False,
         **kwargs,
     ) -> None:
         """
@@ -689,6 +684,7 @@ class DeepFeatureExtractor(FeatureExtractor):
             fill_value (int): Constant pixel value for image padding. Defaults to 255.
             num_workers (int): Number of workers in data loader. Defaults to 0.
             verbose (bool): tqdm processing bar. Defaults to False.
+            with_instance_masking (bool): If pixels outside instance should be masked. Defaults to False.
         """
         self.architecture = self._preprocess_architecture(architecture)
         self.patch_size = patch_size
@@ -698,6 +694,7 @@ class DeepFeatureExtractor(FeatureExtractor):
         else:
             self.stride = stride
         self.downsample_factor = downsample_factor
+        self.with_instance_masking = with_instance_masking
         self.verbose = verbose
         if normalizer is not None:
             self.normalizer = normalizer.get("type", "unknown")
@@ -762,7 +759,8 @@ class DeepFeatureExtractor(FeatureExtractor):
             fill_value=self.fill_value,
             mean=self.normalizer_mean,
             std=self.normalizer_std,
-            transform=transform
+            transform=transform,
+            with_instance_masking=self.with_instance_masking,
         )
         image_loader = DataLoader(
             image_dataset,
@@ -881,8 +879,9 @@ class GridPatchDataset(Dataset):
         """
         super().__init__()
         basic_transforms = [transforms.ToPILImage()]
-        if resize_size is not None:
-            basic_transforms.append(transforms.Resize(resize_size))
+        self.resize_size = resize_size
+        if self.resize_size is not None:
+            basic_transforms.append(transforms.Resize(self.resize_size))
         if transform is not None:
             basic_transforms.append(transform)
         basic_transforms.append(transforms.ToTensor())
@@ -890,26 +889,27 @@ class GridPatchDataset(Dataset):
             basic_transforms.append(transforms.Normalize(mean, std))
         self.dataset_transform = transforms.Compose(basic_transforms)
 
-        x_top_pad, x_bottom_pad = _get_pad_size(
-            image.shape[0], patch_size, stride)
-        y_top_pad, y_bottom_pad = _get_pad_size(
+        self.x_top_pad, self.x_bottom_pad = _get_pad_size(
             image.shape[1], patch_size, stride)
-        pad = torch.nn.ConstantPad2d(
-            (x_bottom_pad, x_top_pad, y_bottom_pad, y_top_pad), 255
+        self.y_top_pad, self.y_bottom_pad = _get_pad_size(
+            image.shape[0], patch_size, stride)
+        self.pad = torch.nn.ConstantPad2d(
+            (self.x_bottom_pad, self.x_top_pad, self.y_bottom_pad, self.y_top_pad), 255
         )
-        self.image = pad(torch.as_tensor(np.array(image)).permute(
+        self.image = self.pad(torch.as_tensor(np.array(image)).permute(
             [2, 0, 1])).permute([1, 2, 0])
         self.patch_size = patch_size
         self.stride = stride
-        self.patches = self._generate_patches()
+        self.patches = self._generate_patches(self.image)
 
-    def _generate_patches(self):
+    def _generate_patches(self, image):
         """Extract patches"""
-        patches = self.image.unfold(0, self.patch_size, self.stride).unfold(
+        n_channels = image.shape[-1]
+        patches = image.unfold(0, self.patch_size, self.stride).unfold(
             1, self.patch_size, self.stride
         )
         self.outshape = (patches.shape[0], patches.shape[1])
-        patches = patches.reshape([-1, 3, self.patch_size, self.patch_size])
+        patches = patches.reshape([-1, n_channels, self.patch_size, self.patch_size])
         return patches
 
     def __getitem__(self, index: int):
@@ -930,6 +930,54 @@ class GridPatchDataset(Dataset):
         return len(self.patches)
 
 
+class MaskedGridPatchDataset(GridPatchDataset):
+    def __init__(
+        self,
+        mask: np.ndarray,
+        **kwargs
+    ) -> None:
+        """
+        Create a dataset for a given image and mask, with extracted patches of (size, size, 3).
+
+        Args:
+            mask (np.ndarray): Binary mask.
+        """
+        super().__init__(**kwargs)
+
+        self.mask_transform = None
+        if self.resize_size is not None:
+            basic_transforms = [transforms.ToPILImage(),
+                                transforms.Resize(self.resize_size),
+                                transforms.ToTensor()]
+            self.mask_transform = transforms.Compose(basic_transforms)
+
+        self.pad = torch.nn.ConstantPad2d(
+            (self.x_bottom_pad, self.x_top_pad, self.y_bottom_pad, self.y_top_pad), 0
+        )
+        self.mask = self.pad(torch.as_tensor(np.array(mask)).permute(
+            [2, 0, 1])).permute([1, 2, 0])
+        self.mask_patches = self._generate_patches(self.mask)
+
+    def __getitem__(self, index: int):
+        """
+        Loads an image and corresponding mask patch for a given index.
+
+        Args:
+            index (int): Patch index.
+
+        Returns:
+            Tuple[int, torch.Tensor, torch.Tensor]: Patch index, image as tensor, mask as tensor.
+        """
+        image_patch = self.dataset_transform(self.patches[index].numpy().transpose([1, 2, 0]))
+        if self.mask_transform is not None:
+            # after resizing, the mask should still be binary and of type uint8
+            mask_patch = self.mask_transform(255*self.mask_patches[index].numpy().transpose([1, 2, 0]))
+            mask_patch = torch.round(mask_patch).type(torch.uint8)
+        else:
+            mask_patch = self.mask_patches[index]
+        return index, image_patch, mask_patch
+
+
 class GridDeepFeatureExtractor(FeatureExtractor):
     def __init__(
         self,
@@ -1111,6 +1159,124 @@ class GridAugmentedDeepFeatureExtractor(GridDeepFeatureExtractor):
         return all_features
 
 
+class MaskedGridDeepFeatureExtractor(GridDeepFeatureExtractor):
+    def __init__(
+        self,
+        tissue_thresh: float = 0.1,
+        **kwargs
+    ) -> None:
+        """
+        Create a deep feature extractor that can process an image with a corresponding tissue mask.
+
+        Args:
+            tissue_thresh (float): Minimum fraction of tissue (vs background) for a patch to be considered as valid.
+        """
+        super().__init__(**kwargs)
+        self.tissue_thresh = tissue_thresh
+
+    def _collate_patches(self, batch):
+        """Patch collate function"""
+        indices = [item[0] for item in batch]
+        patches = [item[1] for item in batch]
+        mask_patches = [item[2] for item in batch]
+        patches = torch.stack(patches)
+        mask_patches = torch.stack(mask_patches)
+        return indices, patches, mask_patches
+
+    def _process(  # type: ignore[override]
+        self, input_image: np.ndarray, mask: np.ndarray
+    ) -> Tuple[pd.DataFrame, pd.DataFrame]:
+        return self._extract_features(input_image, mask)
+
+    def _extract_features(  # type: ignore[override]
+        self, input_image: np.ndarray, mask: np.ndarray
+    ) -> Tuple[pd.DataFrame, pd.DataFrame]:
+        """
+        Generate tissue mask and extract features of patches from a given RGB image.
+        Record which patches are valid and which ones are not.
+
+        Args:
+            input_image (np.ndarray): RGB input image.
+
+        Returns:
+            Tuple[pd.DataFrame, pd.DataFrame]: Boolean index filter, patch features.
+        """
+        if self.downsample_factor != 1:
+            input_image = self._downsample(input_image, self.downsample_factor)
+            mask = self._downsample(mask, self.downsample_factor)
+        mask = np.expand_dims(mask, axis=2)
+
+        # create dataloader for image and corresponding mask patches
+        masked_patch_dataset = MaskedGridPatchDataset(image=input_image,
+                                                      mask=mask,
+                                                      resize_size=self.resize_size,
+                                                      patch_size=self.patch_size,
+                                                      stride=self.stride,
+                                                      mean=self.normalizer_mean,
+                                                      std=self.normalizer_std)
+        patch_loader = DataLoader(masked_patch_dataset,
+                                  shuffle=False,
+                                  batch_size=self.batch_size,
+                                  num_workers=self.num_workers,
+                                  collate_fn=self._collate_patches)
+
+        # create dictionaries where the keys are the patch indices
+        all_index_filter = OrderedDict(
+            {(h, w): None for h in range(masked_patch_dataset.outshape[0])
+                for w in range(masked_patch_dataset.outshape[1])}
+        )
+        all_features = deepcopy(all_index_filter)
+
+        # extract features of all patches and record which patches are (in)valid
+        indices = list(all_features.keys())
+        offset = 0
+        for _, img_patches, mask_patches in tqdm(patch_loader,
+                                                 total=len(patch_loader),
+                                                 disable=not self.verbose):
+            index_filter, features = self._validate_and_extract_features(img_patches, mask_patches)
+            if len(img_patches) == 1:
+                features = features.unsqueeze(dim=0)
+            for i in range(len(index_filter)):
+                all_index_filter[indices[offset+i]] = index_filter[i]
+                all_features[indices[offset+i]] = features[i].cpu().detach().numpy()
+            offset += len(index_filter)
+
+        # convert to pandas dataframes to allow storing as .h5 files
+        all_index_filter = pd.DataFrame(all_index_filter, index=['is_valid'])
+        all_features = pd.DataFrame(np.transpose(np.stack(list(all_features.values()))),
+                                    columns=list(all_features.keys()))
+
+        return all_index_filter, all_features
+
+    def _validate_and_extract_features(
+        self,
+        img_patches: torch.Tensor,
+        mask_patches: torch.Tensor,
+    ) -> Tuple[List[bool], torch.Tensor]:
+        """
+        Record which image patches are valid and which ones are not.
+        Extract features from the given image patches.
+
+        Args:
+            img_patches (torch.Tensor): Batch of image patches.
+            mask_patches (torch.Tensor): Batch of mask patches.
+
+        Returns:
+            Tuple[List[bool], torch.Tensor]: Boolean filter for (in)valid patches, extracted patch features.
+        """
+        # record valid and invalid patches (sufficient area of tissue compared to background)
+        index_filter = []
+        for mask_p in mask_patches:
+            tissue_fraction = (mask_p == 1).sum() / torch.numel(mask_p)
+            if tissue_fraction >= self.tissue_thresh:
+                index_filter.append(True)
+            else:
+                index_filter.append(False)
+
+        # extract features of all patches
+        features = self.patch_feature_extractor(img_patches)
+        return index_filter, features
+
 def _build_augmentations(
     rotations: Optional[List[int]] = None,
     flips: Optional[List[Any]] = None,
